@@ -23,14 +23,18 @@ class RestApiException(serializers.ValidationError):
     default_detail = ""
     detail = ""
 
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.detail = self.default_detail
+
 
 class SMSWaitException(RestApiException):
     default_detail = detail = get_error(conf.SMS_WAIT_TIME)
 
 
 class UserAlreadyExistException(RestApiException):
-    default_detail = detail = get_error( conf.SMS_WAIT_TIME )
+    default_detail = detail = get_error(conf.SMS_USER_ALREADY_EXIST)
 
 
 class SMSCodeNotFoundException(RestApiException):
-    default_detail = detail = get_error( conf.SMS_WAIT_TIME )
+    default_detail = detail = get_error(conf.SMS_CODE_NOT_FOUND)
